@@ -5,8 +5,9 @@ use warnings;
 
 use Data::Dumper;
 
-use FindBin;
-use lib "$FindBin::Bin/../lib";
+use FindBin; # only for this example - load local Udev::FFI module
+use lib "$FindBin::Bin/../lib"; # only for this example - load local Udev::FFI module
+
 use Udev::FFI;
 
 
